[![Ask DeepWiki](https://deepwiki.com/badge.svg)](https://deepwiki.com/Veicm/VSHC)
[![GitHub Issues or Pull Requests](https://img.shields.io/github/issues/Veicm/VSHC?style=flat&link=https%3A%2F%2Fgithub.com%2FVeicm%2FVSHC%2Fissues)](https://github.com/Veicm/VSHC/issues)
[![GitHub Issues or Pull Requests](https://img.shields.io/github/issues-pr/Veicm/VSHC?style=flat&color=%230000ff&link=https%3A%2F%2Fgithub.com%2FVeicm%2FVSHC%2Fpulls)](https://github.com/Veicm/VSHC/pulls)
[![GitHub License](https://img.shields.io/github/license/Veicm/VSHC?style=flat&color=%237f3403)](https://github.com/Veicm/VSHC?tab=Apache-2.0-1-ov-file#readme)

[![GitHub Release](https://img.shields.io/github/v/release/Veicm/VSHC?display_name=tag&style=flat&label=GitHub%20Release&color=%233e85e0)](https://github.com/Veicm/VSHC/releases/latest)
[![PyPI - Version](https://img.shields.io/pypi/v/vshc?style=flat&label=PyPi%20Release&color=%23ffdc4e)](https://pypi.org/project/vshc/)

# VSHC - Veicm's Simple Helper Collection

VSHC (Veicm’s Simple Helper Collection) is a modular and scalable Python utility library providing clean, reusable helper functions for many different purposes. Designed with structured architecture and modern packaging standards for maintainability and extensibility.

## Installation

#### Stable Release (Recommended):

```shell
pip install vshc
```

#### Rolling-release (only for development purposes):

```shell
pip install git+https://github.com/Veicm/VSHC.git
```

#### Version-Specific Installation:

```shell
pip install vshc==0.0.2
```

> or any other version instead of `0.0.2`.

## Documentation

[Documentation (DeepWiki)](https://deepwiki.com/Veicm/VSHC)
